#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from . import mpfun
from models import *
from sqlalchemy.orm import Session
from database import get_local_db

# 系统角色部门表

# 加密和HMAC签名
def sign_row(db: Session, row: SysRoleDept) -> None:
    if row.sign != '':
        return
    
    dept_id = str(row.dept_id) # 部门ID
    role_id = str(row.role_id) # 角色ID

    sign_data = ",".join([dept_id, role_id])
    sign_hmac = mpfun.sign_data(sign_data)
    # print('sign_tbl_user sign_data:', sign_data)
    # print('sign_tbl_user sign_hmac:', sign_hmac)

    row.sign = sign_hmac
    
    db.commit()

# 比较字段合并字符串是否和MAC值匹配上,调用密码服务器[验证HMAC]接口
def sign_valid_row(row: SysRoleDept) -> bool:
    if row.sign == '':
        return True

    # 关键字段合并字符串
    sign_data = get_sign_str(row)
    # print('sys_user sign_data:', sign_data)
    
    # 原HMACSM3数值
    sign_hmac = row.sign
    # print('sign_hmac:', sign_hmac)

    return mpfun.hmac_verify(sign_data, sign_hmac)

# 生成待签名的字符串
def get_sign_str(row: SysRoleDept) -> str:
    dept_id = str(row.dept_id) # 部门ID
    role_id = str(row.role_id) # 角色ID

    # 关键字段合并字符串
    sign_data = ",".join([dept_id, role_id])
    return sign_data

# 生成HAMC签名值
def get_sign_hmac(row: SysRoleDept) -> str:
    sign_data = get_sign_str(row)
    return mpfun.sign_data(sign_data) 

# 对所有数据进行签名
def sign_table():
    print('sign_sys_role_dept table =====>>>')
    with get_local_db() as db:
        rows = db.query(SysRoleDept).filter(SysRoleDept.sign == '').all()
        for row in rows:
            sign_row(db, row)