from sqlalchemy import create_engine, Column, BigInteger, String, Text, DateTime, CHAR,Integer,Float

from database import Base
from datetime import datetime


class RiskManagementInspectionUser(Base):
    __tablename__ = 'risk_management_inspection_user'

    id = Column(BigInteger, primary_key=True, autoincrement=True, comment='ID')
    user_id = Column(BigInteger, nullable=False, comment='用户ID')
    dept_id = Column(BigInteger, nullable=True, comment='部门ID')
    dept_name = Column(String(30),  nullable=True, comment='部门名称')
    ancestors_names = Column(Text,  nullable=True, comment='部门路径')
    user_name = Column(String(30),  nullable=False, comment='用户账号')
    nick_name = Column(String(30), nullable=False, comment='用户昵称')
    phonenumber = Column(String(11),  default='', comment='手机号码')
    area_code = Column(String(11),  default='', comment='责任区划编码')
    area = Column(String(11),  default='', comment='责任区划')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')
    yzy_account = Column(String(50), default=None, comment='粤政易账号')





class RiskManagementInspectionTask(Base):
    __tablename__ = 'risk_management_inspection_task'

    id = Column(BigInteger, primary_key=True, autoincrement=True, comment='ID')
    task_number = Column(String(50),  comment='任务编号')
    inspection_business = Column(String(255), nullable=True, comment='巡查业务，城市隐患巡查、森林防火巡查、重点危化企业巡查、重点水库水位巡查')
    start_time = Column(DateTime, nullable=True, comment='巡查开始时间')
    end_time = Column(DateTime, nullable=True, comment='巡查结束时间')
    inspection_cycle = Column(String(50), nullable=True, comment='巡查周期，每年、每月、每周、每日、一次')
    corn_expression = Column(String(100), nullable=True, comment='corn表达式')
    corn_query = Column(String(100), nullable=True, comment='corn_query')
    inspection_range = Column(String(50), nullable=True, comment='巡查范围，市级、区县级、镇街级、村居级')
    task_status = Column(String(20), nullable=True, comment='任务状态，未开始、进行中、未完成、已完结')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementInspectionTaskChildrenTask(Base):
    __tablename__ = 'risk_management_inspection_task_children_task'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    task_id = Column(BigInteger, nullable=False, comment='ID，任务基础表id')
    task_number = Column(String(50), nullable=True, comment='任务编号')
    type = Column(String(255), nullable=True, comment='巡查业务，城市隐患巡查、森林防火巡查、重点危化企业巡查、重点水库水位巡查')
    tsak_time = Column(DateTime, nullable=True, comment='要求巡查时间')
    cycle = Column(String(50), nullable=True, comment='巡查周期，每年、每月、每周、每日、一次')
    task_range = Column(String(50), nullable=True, comment='巡查范围，市级、区县级、镇街级、村居级')
    task_num = Column(Integer, nullable=False, comment='任务数')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementInspectionTaskChildrenTaskLog(Base):
    __tablename__ = 'risk_management_inspection_task_children_task_log'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    children_task_id = Column(String(50), nullable=False, comment='ID，子任务表id')
    area_code = Column(String(50), nullable=True, comment='区划编码')
    area = Column(Text, nullable=True, comment='区划')
    task_status = Column(String(2), nullable=True, comment='任务进展，已完成、未完成')
    user_id = Column(String(50), nullable=True, comment='用户id')
    nick_name = Column(String(50), nullable=True, comment='巡查人员')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementInspectionTaskChildrenTaskResult(Base):
    __tablename__ = 'risk_management_inspection_task_children_task_result'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    children_task_id = Column(String(50), nullable=False, comment='ID，子任务表id')
    longitude = Column(Float, nullable=True, comment='经度')
    latitude = Column(Float, nullable=True, comment='纬度')
    inspection_point_name = Column(Text, nullable=True, comment='巡查点')
    area_code = Column(String(50), nullable=True, comment='区划编码')
    inspection_result = Column(String(2), nullable=True, comment='巡查结果，正常、异常')
    user_id = Column(String(50), nullable=True, comment='用户id')
    nick_name = Column(String(50), nullable=True, comment='巡查人员')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementFile(Base):
    __tablename__ = 'risk_management_file'

    id = Column(Integer, primary_key=True, autoincrement=True)
    file_id = Column(String(50), nullable=False, comment='文件id')
    file_name = Column(String(255), nullable=False, comment='文件名称')
    file_name_desc = Column(String(255), nullable=False, comment='文件名称原名')
    file_path = Column(String(255), nullable=True, comment='文件存储路径')
    file_size = Column(String(50), nullable=True, comment='文件大小')
    status = Column(String(50), nullable=True, comment='文件状态')
    foreign_key = Column(String(50), nullable=True, comment='文件外键 --技术字段')
    from_scenario = Column(String(50), nullable=True, comment='对应标识 --技术字段')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')

class RiskManagementRiskTask(Base):
    __tablename__ = 'risk_management_risk_task'

    id = Column(BigInteger, primary_key=True, autoincrement=True, comment='ID')
    task_number = Column(String(50), nullable=True, comment='任务编号')
    risk_type = Column(String(255), nullable=True, comment='风险源类型，风险源排查、隐患源排查、危险源排查')
    start_time = Column(DateTime, nullable=True, comment='排查开始时间')
    end_time = Column(DateTime, nullable=True, comment='排查结束时间')
    task_cycle = Column(String(50), nullable=True, comment='排查周期，每年、每月、每周、每日、一次')
    corn_expression = Column(String(100), nullable=True, comment='corn表达式')
    corn_query = Column(String(100), nullable=True, comment='corn_query')
    task_range = Column(String(50), nullable=True, comment='巡查范围，市级、区县级、镇街级、村居级')
    task_status = Column(String(20), nullable=True, comment='任务状态，未开始、进行中、未完成、已完结')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementRiskTaskChildrenTask(Base):
    __tablename__ = 'risk_management_risk_task_children_task'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    task_id = Column(BigInteger, nullable=False, comment='ID，任务基础表id')
    task_number = Column(String(50), nullable=True, comment='任务编号')
    type = Column(String(255), nullable=True, comment='排查业务，城市隐患巡查、森林防火巡查、重点危化企业巡查、重点水库水位巡查')
    tsak_time = Column(DateTime, nullable=True, comment='要求排查时间')
    cycle = Column(String(50), nullable=True, comment='排查周期，每年、每月、每周、每日、一次')
    task_range = Column(String(50), nullable=True, comment='排查范围，市级、区县级、镇街级、村居级')
    task_num = Column(Integer, nullable=False, comment='任务数')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementRiskTaskChildrenTaskLog(Base):
    __tablename__ = 'risk_management_risk_task_children_task_log'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    children_task_id = Column(String(50), nullable=False, comment='ID，子任务表id')
    area_code = Column(String(50), nullable=True, comment='区划编码')
    area = Column(Text, nullable=True, comment='区划')
    task_status = Column(String(2), nullable=True, comment='任务进展，已完成、未完成')
    user_id = Column(String(50), nullable=True, comment='用户id')
    nick_name = Column(String(50), nullable=True, comment='排查人员')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementRiskTaskChildrenTaskResult(Base):
    __tablename__ = 'risk_management_risk_task_children_task_result'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    children_task_id = Column(String(50), nullable=False, comment='ID，子任务表id')
    longitude = Column(Float, nullable=True, comment='经度')
    latitude = Column(Float, nullable=True, comment='纬度')
    inspection_point_name = Column(Text, nullable=True, comment='巡查点')
    area_code = Column(String(50), nullable=True, comment='区划编码')
    inspection_result = Column(String(2), nullable=True, comment='排查结果，正常、异常')
    user_id = Column(String(50), nullable=True, comment='用户id')
    nick_name = Column(String(50), nullable=True, comment='排查人员')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')



class RiskManagementRescueResourcesTask(Base):
    __tablename__ = 'risk_management_rescue_resources_task'

    id = Column(BigInteger, primary_key=True, autoincrement=True, comment='ID')
    task_number = Column(String(50), nullable=True, comment='任务编号')
    type = Column(String(255), nullable=True, comment='采集业务，庇护场所、救援队伍、救援设备')
    start_time = Column(DateTime, nullable=True, comment='采集开始时间')
    end_time = Column(DateTime, nullable=True, comment='采集结束时间')
    task_cycle = Column(String(50), nullable=True, comment='采集周期，每年、每月、每周、每日、一次')
    corn_expression = Column(String(100), nullable=True, comment='corn表达式')
    corn_query = Column(String(100), nullable=True, comment='corn_query')
    task_range = Column(String(50), nullable=True, comment='巡查范围，市级、区县级、镇街级、村居级')
    task_status = Column(String(20), nullable=True, comment='任务状态，未开始、进行中、未完成、已完结')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementRescueResourcesTaskChildrenTask(Base):
    __tablename__ = 'risk_management_rescue_resources_task_children_task'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    task_id = Column(BigInteger, nullable=False, comment='ID，任务基础表id')
    task_number = Column(String(50), nullable=True, comment='任务编号')
    type = Column(String(255), nullable=True, comment='采集业务，庇护场所、救援队伍、救援设备')
    tsak_time = Column(DateTime, nullable=True, comment='要求采集时间')
    cycle = Column(String(50), nullable=True, comment='采集周期，每年、每月、每周、每日、一次')
    task_range = Column(String(50), nullable=True, comment='采集范围，市级、区县级、镇街级、村居级')
    task_num = Column(Integer, nullable=False, comment='任务数')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementRescueResourcesTaskChildrenTaskLog(Base):
    __tablename__ = 'risk_management_rescue_resources_task_children_task_log'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    children_task_id = Column(String(50), nullable=False, comment='ID，子任务表id')
    area_code = Column(String(50), nullable=True, comment='区划编码')
    area = Column(Text, nullable=True, comment='区划')
    task_status = Column(String(2), nullable=True, comment='任务进展，已完成、未完成')
    user_id = Column(String(50), nullable=True, comment='用户id')
    nick_name = Column(String(50), nullable=True, comment='采集人员')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')


class RiskManagementRescueResourcesTaskChildrenTaskResult(Base):
    __tablename__ = 'risk_management_rescue_resources_task_children_task_result'

    id = Column(String(50), primary_key=True, comment='ID，uuid')
    children_task_id = Column(String(50), nullable=False, comment='ID，子任务表id')
    longitude = Column(Float, nullable=True, comment='经度')
    latitude = Column(Float, nullable=True, comment='纬度')
    inspection_point_name = Column(Text, nullable=True, comment='巡查点')
    area_code = Column(String(50), nullable=True, comment='区划编码')
    inspection_result = Column(String(2), nullable=True, comment='采集结果，正常、异常')
    user_id = Column(String(50), nullable=True, comment='用户id')
    nick_name = Column(String(50), nullable=True, comment='采集人员')
    del_flag = Column(String(1), default='0', comment='删除标志（0代表存在 2代表删除）')
    create_dept = Column(BigInteger, default=None, comment='创建部门')
    create_by = Column(BigInteger, default=None, comment='创建者')
    create_time = Column(DateTime, default=datetime.now, comment='创建时间')
    update_by = Column(BigInteger, default=None, comment='更新者')
    update_time = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
    remark = Column(String(500), default=None, comment='备注')