#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from fastapi import APIRouter, Request, Depends, Query, HTTPException, status,WebSocket,WebSocketDisconnect
from common.security import valid_access_token,valid_websocket_token
from fastapi.responses import JSONResponse
from sqlalchemy.orm import Session
from sqlalchemy.sql import func
from common.auth_user import *
from sqlalchemy import  text
from pydantic import BaseModel
from common.BigDataCenterAPI import *
from database import get_db
from typing import List
from models import *
from utils import *
from utils.spatial import *
from utils.ry_system_util import *
from utils.resource_provision_util import *
from common.websocketManager import *
import json
import traceback

router = APIRouter()



@router.post("/create")
async def create_pattern(
    user_id=Depends(valid_access_token),
    body = Depends(remove_xss_json),
    db: Session = Depends(get_db)
):
    try:
        new_type = ResourceProvisionMaterialType(
            parent_id=body['parent_id'],
            material_category_name=body['material_category_name'],
            material_category_level=body['material_category_level'],
            sort_order=body['sort_order'],
            display_status=body['display_status'],
            create_by = user_id
        )
        db.add(new_type)
        db.commit()
        return {"code": 200, "msg": "创建成功", "data": None}
    except Exception as e:
        traceback.print_exc()
        raise HTTPException(status_code=500, detail=f"Internal server error: {str(e)}")



@router.put("/update/{id}")
async def update_pattern(
    id :str ,
    user_id=Depends(valid_access_token),
    body=Depends(remove_xss_json),
    db: Session = Depends(get_db)
):
    try:
        update_type = type_id_get_material_type_info(db,id)
        if not update_type:
            return JSONResponse(status_code=404,content={"code":404,"msg":"type not found"})

        update_type.parent_id = body['parent_id']
        update_type.material_category_name = body['material_category_name']
        update_type.material_category_level=body['material_category_level']
        update_type.sort_order=body['sort_order']
        update_type.display_status=body['display_status']
        update_type.update_by = user_id
        db.commit()
        return {"code": 200, "msg": "更新成功"}
    except Exception as e:
        traceback.print_exc()
        raise HTTPException(status_code=500, detail=f"Internal server error: {str(e)}")

@router.get("/info/{id}")
async def get_pattern_info(
    id: str,
    user_id=Depends(valid_access_token),
    db: Session = Depends(get_db)
):
    try:

        info = type_id_get_material_type_info(db,id)
        if not info:
            return JSONResponse(status_code=404,content={"code":404,"msg":"type not found"})
        parent_material_category_name = ''
        parentinfo = type_id_get_material_type_info(db,info.parent_id)
        if parentinfo is not None:
            # print(parentinfo.material_category_name)
            parent_material_category_name=parentinfo.material_category_name
        data = {"parent_id": info.parent_id,
                "parent_material_category_name":parent_material_category_name,
                "material_category_name": info.material_category_name,
                "material_category_level": info.material_category_level,
                "sort_order": info.sort_order,
                "display_status": info.display_status,
                "create_time": info.create_time,
                "create_by": info.create_by,
                "id": info.id}
        return {"code": 200, "msg": "获取成功", "data": data}
    except Exception as e:
        traceback.print_exc()
        raise HTTPException(status_code=500, detail=f"Internal server error: {str(e)}")

@router.get("/list")
async def get_pattern_list(
    user_id=Depends(valid_access_token),
    name: str = Query(None, description='名称'),
    page: int = Query(1, gt=0, description='页码'),
    pageSize: int = Query(None, gt=0, description='每页条目数量'),
    db: Session = Depends(get_db)
):
    try:
        query = db.query(ResourceProvisionMaterialType)
        query = query.filter_by(del_flag='0')
        if name:
            query = query.filter(ResourceProvisionMaterialType.material_category_name.like(f'%{name}%'))
        total_items = query.count()
        # 排序
        if pageSize is None:
            pageSize=total_items
        query = query.order_by(ResourceProvisionMaterialType.sort_order.asc())
        # 执行分页查询
        lists = query.offset((page - 1) * pageSize).limit(pageSize).all()
        data = [{"parent_id": info.parent_id,
                "material_category_name": info.material_category_name,
                "material_category_level": info.material_category_level,
                "sort_order": info.sort_order,
                "display_status": info.display_status,
                "create_time": info.create_time,
                "create_by": info.create_by,
                "id": info.id} for info in lists]
        return {"code": 200, "msg": "查询成功", "data": data,
                "total": total_items,
                "page": page,
                "pageSize": pageSize,
                "totalPages": (total_items + pageSize - 1) // pageSize
                }
    except Exception as e:
        traceback.print_exc()
        raise HTTPException(status_code=500, detail=f"Internal server error: {str(e)}")

@router.delete("/delete/{id}")
async def delete_pattern(
    id: str,
    user_id=Depends(valid_access_token),
    db: Session = Depends(get_db)
):
    try:
        # 检查图案是否存在
        info = type_id_get_material_type_info(db, id)
        if not info:
            return JSONResponse(status_code=404, content={"code": 404, "msg": "type not found"})
        info.del_flag='2'
        db.commit()
        return {"code": 200, "msg": "删除成功"}
    except Exception as e:
        traceback.print_exc()
        raise HTTPException(status_code=500, detail=f"Internal server error: {str(e)}")

@router.get('/treeselect')
async def gettreeselect(request: Request,db: Session = Depends(get_db), user_id: int = Depends(valid_access_token)):
    def build_type_tree(menus, parent_dept):
        type_tree = []
        for type_info in menus:
            type_i = {
                "id": type_info.id,
                "label": type_info.material_category_name,
                "level":type_info.material_category_level,
                "parentId": type_info.parent_id,
                "weight": type_info.sort_order
            }
            # print(dept_info.dept_id)
            children = parent_id_get_type_info(db, type_info.id)
            if len(children) > 0:
                children_types = build_type_tree(children, type_i)
                type_i["children"] = children_types
            type_tree.append(type_i)
        return type_tree

    result = build_type_tree(parent_id_get_type_info(db, 0), None)
    return {
        "code": 200,
        "msg": "操作成功",
        "data": result
    }
